//
//   @file    gprint.cxx         
//   
//            builds the grid table for the downloads.htm file  
//          
//
//   @author M.Sutton
// 
//   Copyright (C) 2013 M.Sutton (sutt@cern.ch)    
//
//   $Id: gprint.cxx, v0.0   Wed 26 Jun 2013 23:05:02 CEST sutt $


#include <iostream>
// #include <ios>
#include <fstream>
#include <string>
#include <vector>

#include "applcolours.ihtml"

#include "grids.h"



/// the real row class - has a "row" (not a tr) for each grid/data 
/// set combination

class row { 

public:

  /// fill the fields of the row
  row( std::string* s) { 
    m_header  = s[0];
    m_beam    = s[1];
    m_arxiv   = s[2];
    m_info    = s[3];
    m_hepdata = s[4];
    m_applgrid = s[5];
    m_appldoc  = s[6];
    m_extradoc = s[7];
  }

  /// get the beam energy (so we can have different tables
  std::string beam() const { return m_beam; }

  /// actually print out the row
  void print( std::ostream& stream=std::cout ) {

    //    stream = s;

    static std::string tc[2] = { TABCOLOUR1, TABCOLOUR2 }; 
    static int icol = 1;
    
    std::string colour = tc[icol%2]; icol++;

    stream << "\n<!-- " << m_header << " ----->\n\n\n";


    stream << tabrow( m_header+" "+m_extradoc, colour ); 

    stream << "<tr bgcolor=" << colour << ">" << std::endl;
    stream << tabcol( anchor( std::string("http://arxiv.org/abs/")+m_arxiv, "arXiv:"+m_arxiv ) );
    stream << tabcol( m_info );
    stream << "</tr>" << std::endl;

    stream << "<tr bgcolor=" << colour << ">" << std::endl;
    stream << tabcol( anchor( m_hepdata, "hepdata" ) ); 
    stream << tabcol( "" );
    stream << "</tr>" << std::endl;
  

    stream << "<tr bgcolor=" << colour << " valign=\"top\">" << std::endl;
    stream << tabcol( anchor( m_applgrid, "grid tarball" ) + " contains" ); 
    stream << tabcol( m_appldoc );
    stream << "</tr>\n" << std::endl;

  }

  void printsummary( std::ostream& stream=std::cout ) {

    std::string label = m_header;
    
    size_t pos  = label.find("data");
    
    /// replace the (second more than one) instance of "data" in the data set header
    if ( pos!=std::string::npos ) { 
      size_t second = label.find( "data", pos+1 );
      if ( second!=std::string::npos ) pos = second;
      label.replace( pos, 4, "-" );     
    }
    
    stream << "<font face=\"Arial, Geneva\" color=\"" 
	   << FONTCOLOUR2 << "\" size=\"2\">" <<  label << "\n" 
	   << "<a href=\"" <<  m_applgrid << "\"> <font face=\"Arial, Geneva\" color=\"" << FONTLINKCOLOUR << "\" size=\"2\"> grids </font></a>\n"
	   << "</font>\n<br />\n";
  } 
  

private:


  /// some basic table entry printout routines for an easier life 
  
  /// add a table column
  std::string tabcol(const std::string& s) { 
    //  std::cout << "  <td colspan=\"" << n << "\" >\n";
    std::string _stream = "  <td>\n   " + s + "\n  </td>\n";
    return _stream;
  }
  
  
  /// add a row header 
  std::string tabrow(const std::string& s, const std::string& colour="ffffff") {
    std::string _stream = "<tr bgcolor=\"" + colour + "\"><td colspan=\"2\">" + s + "</td></tr>\n";
    return _stream;
  }
  
  
  /// get the text for an anchor
  std::string anchor( const std::string& link, const std::string& s) { 
    std::string ss = "<a target=\"new\" href=\"" + link + "\">" + s + "</a>";
    return ss;
  }


private:


  std::string m_header;

  std::string m_beam;
  
  std::string m_info;

  std::string m_arxiv;
  std::string m_hepdata;

  std::string m_applgrid;
  std::string m_appldoc;

  std::string m_extradoc;

};


int main() { 

  /// read all the rows from the data base

  std::vector<row> rows;
  
  for ( int i=0 ; i<8 ; i++ ) rows.push_back( db[i] );

  /// draw the table

  //  std::cout << "<html>\n";






  ///
  /// create the main downloads table 
  ///

  std::fstream file;
  file.open("grids.ihtml", std::ios_base::out);
  
  std::ostream& mystream = file;
  
  mystream << "<!-- emacs: this is -*- html -*- -->\n";
  mystream << "<!-- WARNING!!! THIS FILE IS AUTOMATICALLY GENERATED - DO NOT EDIT, YOUR CHANGES WILL BE LOST -->\n\n";


  mystream << "<table id=\"codetable\" align=\"middle\" border=\"0\" cellpadding=\"5em\" cellspacing=\"0\">\n"
	    << "<!-- ------------------------------------------------->\n"
	    << "<!--  LHC  ------------------------------------------->\n"
	    << "<!-- ------------------------------------------------->\n"
	    << "<tbody>\n";
  
  /// 2.76 TeV entries 

  mystream << "\n<!-- 2.76 TeV beam energy ---------------------------------------->\n\n";

  mystream << "<tr bgcolor=\"" << TABCOLOUR0 << "\">\n"
	    << "<td colspan=\"3\" align=\"left\"><b>LHC: pp @ sqrt(s) = 2.76TeV</b> </td>\n"
	    << "</tr>" << std::endl;
  
  for ( int i=0 ; i<rows.size() ; i++ ) if ( rows[i].beam()=="2.76" ) rows[i].print(mystream);


  /// 7 TeV entries
  mystream << "\n<!-- 7 TeV beam energy ---------------------------------------->\n\n";

  mystream << "<tr bgcolor=\"" << TABCOLOUR0 << "\">\n"
	    << "<td colspan=\"3\" align=\"left\"><b>LHC: pp @ sqrt(s) = 7TeV</b> </td>\n"
	    << "</tr>" << std::endl;

  for ( int i=0 ; i<rows.size() ; i++ ) if ( rows[i].beam()=="7" ) rows[i].print(mystream);
  
  mystream << "</tbody>\n</table>" << std::endl;

  //  mystream << "</html>\n";

  mystream << std::endl;

  file.close();




  ///
  /// create the short grid part of the side bar
  ///

  std::fstream fside;
  fside.open( "gridsbar.ihtml", std::ios_base::out );

  fside << "<!-- emacs: this is -*- html -*- -->\n";
  fside << "<!-- WARNING!!! THIS FILE IS AUTOMATICALLY GENERATED - DO NOT EDIT, YOUR CHANGES WILL BE LOST -->\n\n";
  
  //  fside << "<spacer type=vertical height=300 size=100>\n";
  fside << "<br />\n";
  fside << "<font face=\"Arial, Geneva\" color=\"" << FONTCOLOUR2 << "\" size=\"2\"> Grids for sqrt(s)=2.76 TeV:</font>\n<br />\n";
  for ( int i=0 ; i<rows.size() ; i++ )  if ( rows[i].beam()=="2.76" ) rows[i].printsummary(fside);

  //  fside << "<spacer type=vertical height=300 size=100>\n";
  fside << "<br />\n";
  fside << "<font face=\"Arial, Geneva\" color=\"" << FONTCOLOUR2 << "\" size=\"2\"> Grids for sqrt(s)=7 TeV:</font>\n<br />\n";
  for ( int i=0 ; i<rows.size() ; i++ )  if ( rows[i].beam()=="7" ) rows[i].printsummary(fside);

  fside.close();

  return 0;
}
